(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[845],{13910:function(i,t,e){(window.__NEXT_P=window.__NEXT_P||[]).push(["/settings/custom-fields/[id]",function(){return e(63730)}])},63730:function(i,t,e){"use strict";e.r(t);var n=e(24246),s=e(86677),u=e(77213),l=e(77830),d=e(58754),r=e(47094),o=e(32885);t.default=()=>{var i;let{id:t}=(0,s.useRouter)().query,{data:e,isLoading:a}=(0,o.s0)({id:t});return(0,n.jsxs)(u.Z,{title:"Edit custom field",mainProps:{maxWidth:"720px"},children:[(0,n.jsx)(d.Z,{heading:"Custom fields",breadcrumbItems:[{title:"All custom fields",href:l.WC},{title:null!==(i=null==e?void 0:e.name)&&void 0!==i?i:t}]}),(0,n.jsx)(r.Z,{initialField:e,isLoading:a})]})}}},function(i){i.O(0,[8765,2962,5643,2888,9774,179],function(){return i(i.s=13910)}),_N_E=i.O()}]);