(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[9914],{92973:function(e,t,n){(window.__NEXT_P=window.__NEXT_P||[]).push(["/settings/custom-fields/new",function(){return n(85127)}])},85127:function(e,t,n){"use strict";n.r(t);var s=n(24246),i=n(77213),u=n(77830),c=n(58754),f=n(47094);t.default=()=>(0,s.jsxs)(i.Z,{title:"New custom field",mainProps:{maxWidth:"720px"},children:[(0,s.jsx)(c.Z,{heading:"Custom fields",breadcrumbItems:[{title:"All custom fields",href:u.WC},{title:"Create new"}]}),(0,s.jsx)(f.Z,{})]})}},function(e){e.O(0,[8765,2962,5643,2888,9774,179],function(){return e(e.s=92973)}),_N_E=e.O()}]);